'use strict';
const Schema = require('mongoose').Schema;
const metaPlugin = require('naf-framework-mongoose/lib/model/meta-plugin');
const { Secret } = require('naf-framework-mongoose/lib/model/schema');

// 企业认证信息表
const CompanyidentifySchema = {
  uid: { type: String, required: true, maxLength: 200 }, // 关联企业用户id                  必填
  company_name: { type: String, required: true, maxLength: 200 }, // 企业名称               必填
  reg_num: { type: String, required: true, maxLength: 200 }, // 统一社会信用代码            必填
  type: { type: String, required: true, maxLength: 200 }, //      公司类型                  必填
  address: { type: String, required: true, maxLength: 200 }, // 地址                        必填
  business: { type: String, required: true, maxLength: 200 }, // 经营范围                   必填
  capital: { type: String, required: true, maxLength: 200 }, // 注册资本                    必填
  establish_date: { type: String, required: true, maxLength: 200 }, // 成立日期             必填
  valid_period: { type: String, required: true, maxLength: 200 }, //    公司营业期限终止日期      "长期"表示为"29991231"
  person: { type: String, required: true, maxLength: 200 }, //      法定代表人      必填
  opening_bank: { type: String, required: true, maxLength: 200 }, //      开户行      必填
  status: { type: String, required: false, maxLength: 200, default: '1' }, // 认证状态，0-认证中，1-认证通过，2-认证失败  改为默认认证通过

  // business_license: { type: String, required: false, maxLength: 200 }, // 营业执照图片
  // establish_date: { type: String, required: false, maxLength: 200 }, // 成立日期
  // due_date: { type: String, required: false, maxLength: 200 }, // 营业到期日期
  // type: { type: String, required: false, maxLength: 200 }, // 企业类型
  // registered_capital: { type: String, required: false, maxLength: 200 }, // 注册资本
  // total_assets: { type: String, required: false, maxLength: 200 }, // 资产总额
  // taking: { type: String, required: false, maxLength: 200 }, // 营业收入
  // number: { type: String, required: false, maxLength: 200 }, // 从业人员数量
  // belong_type: { type: String, required: false, maxLength: 200 }, // 企业所属类型
  profession_one: { type: String, required: false, maxLength: 200 }, // 所属一级行业
  profession_two: { type: String, required: false, maxLength: 200 }, // 所属二级行业
  profession_three: { type: String, required: false, maxLength: 200 }, // 所属三级行业
  profession_four: { type: String, required: false, maxLength: 200 }, // 所属四级行业
  belong_addr_city: { type: String, required: false, maxLength: 200 }, // 企业所属地-市
  belong_addr_area: { type: String, required: false, maxLength: 200 }, // 企业所属地-区
  // business_addr: { type: String, required: false, maxLength: 200 }, // 经营地址
  // registered_addr: { type: String, required: false, maxLength: 200 }, // 注册地址
  // business_scope: { type: String, required: false, maxLength: 200 }, // 经营范围
  // introduction: { type: String, required: false }, // 企业简介
  // card_front: { type: String, required: false, maxLength: 200 }, // 身份证正面图
  // card_back: { type: String, required: false, maxLength: 200 }, // 身份证背面图
  // representative: { type: String, required: false, maxLength: 200 }, // 法定代表人
  // representative_id: { type: String, required: false, maxLength: 200 }, // 法人证件号
  // representative_phone: { type: String, required: false, maxLength: 200 }, // 法人手机号
  // status: { type: String, required: false, maxLength: 200, default: '0' }, // 认证状态，0-认证中，1-认证通过，2-认证失败
};


const schema = new Schema(CompanyidentifySchema, { toJSON: { virtuals: true } });
schema.index({ id: 1 });
schema.index({ uid: 1 });
schema.plugin(metaPlugin);

module.exports = app => {
  const { mongoose } = app;
  return mongoose.model('Companyidentify', schema, 'company_identify');
};
